package com.install4j.api.screens;

import com.install4j.api.beans.AbstractBean;
import com.install4j.api.context.ProgressInterface;
import com.install4j.api.context.UninstallerContext;
import com.install4j.api.context.UserCanceledException;
import com.install4j.api.events.InstallerEvent;
import com.install4j.api.events.InstallerEventListener;

/**
 * Abstract base class for uninstaller screens.
 * All methods that have a reasonable default answer are overridden in the class.
 * This class saves the uninstaller context that is set by the framework and provides a getter for it.
 *
 * @author ej-technologies GmbH
 */
public abstract class AbstractUninstallerScreen extends AbstractBean implements UninstallerScreen, InstallerEventListener {

    private UninstallerContext context;

    @Override
    public void setUninstallerContext(UninstallerContext context) {
        this.context = context;
    }

    @Override
    public boolean isNextVisible() {
        return true;
    }

    @Override
    public boolean isPreviousVisible() {
        return true;
    }

    @Override
    public boolean isCancelVisible() {
        return true;
    }

    @Override
    public boolean isHiddenForNext() {
        return false;
    }

    @Override
    public boolean isHiddenForPrevious() {
        return false;
    }

    @Override
    public void activated() {
    }

    @Override
    public void deactivated() {
    }

    @Override
    public void installerEvent(InstallerEvent event) {
    }

    @Override
    public boolean next() {
        return true;
    }

    @Override
    public boolean previous() {
        return true;
    }

    @Override
    public boolean cancel() {
        return true;
    }

    @Override
    public void willActivate() {

    }

    @Override
    public boolean isHidden() {
        return false;
    }

    @Override
    public boolean handleUnattended() {
        return true;
    }

    @Override
    public boolean handleConsole(Console console) throws UserCanceledException {
        console.printHeader(getTitle());
        return true;
    }

    @Override
    public ProgressInterface getProgressInterface(ProgressInterface defaultProgressInterface) {
        return defaultProgressInterface;
    }

    @Override
    public boolean hasTitlePanel() {
        return true;
    }

    @Override
    public boolean isShowIndex() {
        return true;
    }

    @Override
    public boolean isCreateLazily() {
        return false;
    }

    @Override
    public boolean hasDefaultInsets() {
        return true;
    }

    @Override
    public boolean hasDefaultButtons() {
        return true;
    }

    /**
     * Returns the {@code UninstallerContext} that the framework has associated with
     * this custom screen in {@code setUninstallerContext}.
     * @return the uninstaller context.
     */
    public UninstallerContext getUninstallerContext() {
        return context;
    }

}
