package com.install4j.api.update;

import com.install4j.api.beans.ErrorHandlingCallback;
import com.install4j.api.context.UserCanceledException;
import com.install4j.runtime.installer.helper.apiimpl.UpdateCheckerImpl;

import java.io.IOException;

/**
 * Utility class to download an update descriptor programmatically from a given URL. In an installer
 * application, is is recommended to use the "Check for update" action instead. This class is mainly
 * intended for checking for updates in your application.
 * <p>In order to use this class in your application, please include {@code resource/i4jruntime.jar} from your
 * install4j installation into your class path. You do not need to distribute this file
 * along with your application, install4j will do this automatically for you.
 * </p>
 *
 * @author ej-technologies GmbH
 * @see UpdateDescriptor
 */
public class UpdateChecker {

    /**
     * Convenience method for {@link #getUpdateDescriptor(UpdateCheckRequest)}.
     *
     * @param urlSpec               see {@link UpdateCheckRequest#urlSpec(String)}
     * @param displayMode           see {@link UpdateCheckRequest#applicationDisplayMode(ApplicationDisplayMode)}
     * @throws UserCanceledException if the user cancels the proxy dialog
     * @throws IOException           if the download fails
     */
    public static UpdateDescriptor getUpdateDescriptor(String urlSpec, ApplicationDisplayMode displayMode) throws UserCanceledException, IOException {
        return getUpdateDescriptor(urlSpec, displayMode, null);
    }

    /**
     * Convenience method for {@link #getUpdateDescriptor(UpdateCheckRequest)}.
     *
     * @param urlSpec               see {@link UpdateCheckRequest#urlSpec(String)}
     * @param displayMode           see {@link UpdateCheckRequest#applicationDisplayMode(ApplicationDisplayMode)}
     * @param errorHandlingCallback see {@link UpdateCheckRequest#errorHandlingCallback(ErrorHandlingCallback)}
     * @throws UserCanceledException if the user cancels the proxy dialog
     * @throws IOException           if the download fails
     */
    public static UpdateDescriptor getUpdateDescriptor(String urlSpec, ApplicationDisplayMode displayMode, ErrorHandlingCallback errorHandlingCallback) throws UserCanceledException, IOException {
        UpdateCheckRequest updateCheckRequest = new UpdateCheckRequest(urlSpec).applicationDisplayMode(displayMode).errorHandlingCallback(errorHandlingCallback);
        return getUpdateDescriptor(updateCheckRequest);
    }


    /**
     * Download an {@code updates.xml} file programatically from a given URL and returns an
     * {@link UpdateDescriptor} instance. The {@link UpdateCheckRequest} specifies the URL and other connection options.
     *
     * @param updateCheckRequest the update check request
     * @return the update descriptor
     * @throws UserCanceledException if the user cancels the proxy dialog
     * @throws IOException           if the download fails
     */
    public static UpdateDescriptor getUpdateDescriptor(UpdateCheckRequest updateCheckRequest) throws UserCanceledException, IOException {
        return UpdateCheckerImpl.getUpdateDescriptor(updateCheckRequest);
    }

}
